#!/bin/sh


# this should point to the directory with ColdFusions lib directory.
# if this is blank, this is probably a J2EE deployment and this should point
# to the /WEB-INF/cfusion directory
CFUSION_HOME=$INSTALL_CFUSION_HOME$

# This needs to point at the jar file with the J2EE class files in it.
# It defaults to a value that is valid for the server install, but for
# a J2EE install you will need to modify it to point to the appropriate jar file.
J2EEJAR=$INSTALL_J2EEJAR$

# This needs to point to the WEB-INF directory for ColdFusion.
WEBINF=$INSTALL_WEBINF$

if [ "$DOLLAR$CFUSION_HOME" = "" ]; then
    echo CFUSION_HOME not set.  Please set CFUSION_HOME to your CFMX root directory
	exit 1
fi

if [ "$DOLLAR$WEBINF" = "" ]; then
    echo WEBINF not set.  Please set WEBINF to your WEB-INF directory for ColdFusion.
	exit 1
fi

. $DOLLAR$CFUSION_HOME/bin/findjava.sh

CLASSES=\"$DOLLAR$J2EEJAR:$DOLLAR$WEBINF/lib/cfmx_bootstrap.jar:$DOLLAR$WEBINF/lib/cfx.jar\"
PATH=$DOLLAR$PATH:$DOLLAR$CFUSION_HOME/runtime/bin
export PATH
argv0=$DOLLAR$0
argv="$DOLLAR$*"
msg()
	{
		echo -e "$DOLLAR$@"  >&2
	}
menu()
	{
	echo
	 msg 'Useage: 
To compile files into .class files:

    ./cfcompile.sh -cfuser <username> -webroot <directory> -dir <directory>

To compile files into a binary format without the need for source:

    ./cfcompile.sh -deploy -cfuser <username> -webroot <directory> -dir <directory> -deploydir <directory>		

-cfuser	Specify the ColdFusion Runtime user

-webroot  Specify the directory location of the webroot

-dir  Specify the fully qualified name of the directory where 
      the files are located to be compiled. This directory must be
      under the webroot directory.  If not specified, all ColdFusion
      templates in the webroot directory will be compiled.  This is required
      for the -deploy option

-deploydir
	Specify the fully qualified name of the directory where the
	compiled files are to be placed.  This directory may not be the
	same as the source directory.'

		exit 0
	}

if [ "$DOLLAR$1" = "-deploy" ]; then
    shift 1
	while [ $DOLLAR$# -gt 0 ]; do
		case $DOLLAR$1 in
			-h)    
				deploy_menu
				shift
				;;
			-cfuser)  
				cfuser=$DOLLAR$2	
				shift 2
				;;
			-dir)  
				srcdir=$DOLLAR$2	
				shift 2
				;;
			-deploydir)  
				deploydir=$DOLLAR$2	
				shift 2
				;;
			-webroot)  
				webroot=$DOLLAR$2	
				shift 2
				;;
			*)
				shift 1
				;;
	esac
 done

if [ "$DOLLAR$cfuser" = "" ]; then
	echo "ColdFusion runtime User  not set.  Please set the ColdFusion runtime user" 1>&2
	menu
	exit 1
fi

if [ "$DOLLAR$webroot" = "" ]; then
	echo "Webroot is not set. Please specify the location of the webroot directory " 1>&2
	menu
	exit 1
fi

if [ "$DOLLAR$srcdir" = "" ]; then
	echo "Source directory is not set.  Please specify the location of the directory you wish to compile " 1>&2
	menu
	exit 1
fi

if [ "$DOLLAR$deploydir" = "" ]; then
	echo "Output directory is not set.  Please specify the location of the directory you wish to place the deployable files in " 1>&2
	menu
	exit 1
fi

if [ "$DOLLAR$CFUSION_HOME" = "" ]; then
	echo "CFUSION_HOME not set.  Please set CFUSION_HOME to your CFMX root directory" 1>&2
	exit 1
fi

case `uname` in
 SunOS)
	OS=Solaris
	su $DOLLAR$cfuser -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -deploy -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot -cfroot $DOLLAR$CFUSION_HOME -srcdir $DOLLAR$srcdir -deploydir $DOLLAR$deploydir"
        ;;
 HP-UX)
        OS=HPUX
        su $DOLLAR$cfuser -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -deploy -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot -cfroot $DOLLAR$CFUSION_HOME -srcdir $DOLLAR$srcdir -deploydir $DOLLAR$deploydir"
        ;;

 Linux)
        OS=Linux
        su $DOLLAR$cfuser -s /bin/sh -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -deploy -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot -cfroot $DOLLAR$CFUSION_HOME -srcdir $DOLLAR$srcdir -deploydir $DOLLAR$deploydir"
        ;;

 Darwin)
        OS=Darwin
        su $DOLLAR$cfuser -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -deploy -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot -cfroot $DOLLAR$CFUSION_HOME -srcdir $DOLLAR$srcdir -deploydir $DOLLAR$deploydir"
        ;;

 *)

        echo "Your OS: `uname` is unsupported"
        echo "exiting"
        exit 1
        ;;

esac
    exit 0
fi

	while [ $DOLLAR$# -gt 0 ]; do 
		case $DOLLAR$1 in
			-h)    
				menu
				shift
				;;
			-cfuser)  
				cfuser=$DOLLAR$2	
				shift 2
				;;
			-dir)  
				dir=$DOLLAR$2	
				shift 2
				;;
			-webroot)  
				webroot=$DOLLAR$2	
				shift 2
				;;
			*)
				#ignore
				shift 1
				;;
	esac
 done

if [ "$DOLLAR$cfuser" = "" ]; then
	echo "ColdFusion runtime User  not set.  Please set the ColdFusion runtime user" 1>&2
	menu
	exit 1
fi

if [ "$DOLLAR$webroot" = "" ]; then
	echo "Webroot is not set. Please specify the location of the webroot directory " 1>&2
	menu
	exit 1
fi

if [ "$DOLLAR$dir" = "" ]; then
	dir=$DOLLAR$webroot
fi

if [ "$DOLLAR$CFUSION_HOME" = "" ]; then
	echo "CFUSION_HOME not set.  Please set CFUSION_HOME to your CFMX root directory" 1>&2
	exit 1
fi

case `uname` in
 SunOS)
	OS=Solaris
	su $DOLLAR$cfuser -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -cfroot $DOLLAR$CFUSION_HOME -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot $DOLLAR$dir"
        ;;

        HP-UX)
                OS=HPUX
               su $DOLLAR$cfuser -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -cfroot $DOLLAR$CFUSION_HOME -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot $DOLLAR$dir"
        ;;

        Linux)
                OS=Linux
               su $DOLLAR$cfuser -s /bin/sh -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -cfroot $DOLLAR$CFUSION_HOME -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot $DOLLAR$dir"
        ;;

        Darwin)
                OS=Darwin
               su $DOLLAR$cfuser -c "$DOLLAR${_JAVACMD} -cp $DOLLAR$CLASSES -Dcoldfusion.classPath=$DOLLAR$CFUSION_HOME/lib/updates,$DOLLAR$CFUSION_HOME/lib -Dcoldfusion.libPath=$DOLLAR$CFUSION_HOME/lib coldfusion.tools.CommandLineInvoker Compiler -cfroot $DOLLAR$CFUSION_HOME -webinf $DOLLAR$WEBINF -webroot $DOLLAR$webroot $DOLLAR$dir"
        ;;

        *)

        echo "Your OS: `uname` is unsupported"
        echo "exiting"
        exit 1
        ;;

esac











